scriptLocation: Find Chapter Script Files

View source: R/scriptLocation.R

scriptLocationR Documentation

Find Chapter Script Files

Description

This function identifies the physical location on the user's computer where the chapter R scripts are located.

Usage

scriptLocation()

Author(s)

Max Kuhn

Examples


scriptLocation()


AppliedPredictiveModeling documentation built on July 7, 2026, 1:06 a.m.